View source: R/permutation.order.R
| permutation.order | R Documentation |
It finds the vector of permutation to permute data by its largest absolute value in each eigenvector. It sets the order by specified number of factors, and the rest is ordered as they were.
permutation.order(data, n.factors)
data |
The dataset |
n.factors |
Number of factors |
The numeric vector of permutation
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.