| plot_B.CI | R Documentation |
The functions builds a column-wise plots of factor loadings. The parameters fixed at 1 are displayed with red dashed vertical lines.
plot_B.CI(
Gibbs,
true.val = NA,
burnin = NA,
permutation = NA,
main.bool = TRUE,
layout.dim = NA
)
Gibbs |
Result of Gibbs sampler from DIFM function |
true.val |
True values of factor loadings. If not available, NA. |
burnin |
Number of burn-in. If not specified, it uses the first tenths as burn-in period. |
permutation |
Permutation of variables. If not specified, no permutation. |
main.bool |
Add title of the plots. |
layout.dim |
Dimension of panel layout for multiple factor loadings. If not specificed, factor loadings plots are layout in one column. |
Factor loadings credible interval plots
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.