| plot_X.CI | R Documentation |
The functions builds the plot of 95% confidence intervals of the common realizations, X. The black solid lines are the posterior mean and the dased lines are the 95% confidence intervals.
plot_X.CI(Gibbs, burnin = NA, main.bool = FALSE, layout.dim = NA)
Gibbs |
Result of Gibbs sampler from DIFM function. |
burnin |
Number of burn-in. If not specified, it uses the first tenths as burn-in period. |
main.bool |
Add title of the plots. |
layout.dim |
Dimension of panel layout for multiple common factors. If not specificed, common factor plots are layout in one column. |
Credible interval plots of common factors
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.