plot_sigma2.CI: A credible interval plot of posterior of sigma squared

View source: R/plot_sigma2.CI.R

plot_sigma2.CIR Documentation

A credible interval plot of posterior of sigma squared

Description

It returns a credible interval plot of idiosyncratic variance, sigma squared. The lines are 95

Usage

plot_sigma2.CI(Gibbs, burnin = NA, permutation = NA, main.bool = TRUE)

Arguments

Gibbs

Result of Gibbs sampler from DIFM function.

burnin

Number of burn-in. If not specified, it uses the first tenths as burn-in period.

permutation

Permutation of variables. If not specified, no permutation.

main.bool

Add title of the plots.

Value

A credible interval plot of sigma squared


DIFM documentation built on Nov. 11, 2025, 9:06 a.m.